from setuptools import setup
setup(name="Shuvo",
version='0.1',
description='this is a simple pip modul and test',
long_description='THia is simpile modul crate by mahdi hasan',
package=['Shuvo'],
install_requires=[])